@@ -4,7 +4,7 @@
 modname = 'registration'
 distname = 'cubicweb-registration'
 
-numversion = (0, 5, 0)
+numversion = (0, 6, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -20,8 +20,7 @@ classifiers = [
     ]
 
 __depends__ = {'cubicweb': '>= 3.19.0',
-               'pycrypto': None,
-               'PIL': None,
+               'Pillow': None,
                }
 
 # packaging ###
