@@ -4,6 +4,6 @@ options = (
      {'type' : 'string',
       'default': u"this is my dummy registration cypher seed",
       'help': 'seed used to cypher registration data in confirmation email link',
-      'group': 'registration', 'inputlevel': 2,
+      'group': 'registration', 'level': 2,
       }),
     )
