@@ -1,7 +1,7 @@
 """anonymous registration form and views
 
 :organization: Logilab / SecondWeb
-:copyright: 2009-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:copyright: 2009-2014 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
@@ -33,7 +33,7 @@ class RegistrationForm(forms.FieldsForm):
         return self._cw.build_url(u'registration_sendmail')
 
     # properly name fields according to validation errors that may be raised by
-    # Repository.register_user
+    # the register_user service
     login = ff.StringField(widget=fw.TextInput(), role='subject',
                            # we don't want to see 'authenticate'
                            label=_('i18n_register_login'),
@@ -102,7 +102,7 @@ See you soon on %(base_url)s !
         data.setdefault(qname('surname'), '')
         if not (data.get(qname('firstname')) or data.get(qname('surname'))):
             data[qname('firstname')] = data[qname('login')]
-        data.update({'base_url': self._cw.vreg.config['base-url'],
+        data.update({'base_url': self._cw.base_url(secure=True),
                      'url': activationurl})
         content = self._cw._(self.content) % data
         subject = self._cw._(self.subject) % data
@@ -112,7 +112,7 @@ See you soon on %(base_url)s !
     def activation_url(self, data):
         data.pop(qname('upassword') + '-confirm', None)
         key = crypto.encrypt(data, self._cw.vreg.config['registration-cypher-seed'])
-        return self._cw.build_url('registration_confirm', key=key)
+        return self._cw.build_url('registration_confirm', key=key, __secure__=True)
 
     def success_redirect_url(self):
         msg = self._cw._(u'Your registration email has been sent. Follow '
@@ -139,10 +139,13 @@ class RegistrationConfirmController(controller.Controller):
         req.form = data # hijack for proper validation error handling
         err_raised = False
         try:
-            self.appli.repo.register_user(login, password,
-                                          email=data.get(qname('email_address')),
-                                          firstname=data.get(qname('firstname')),
-                                          surname=data.get(qname('surname')))
+            with self.appli.repo.internal_cnx() as cnx:
+                cnx.call_service('register_user',
+                                 login=login, password=password,
+                                 email=data.get(qname('email_address')),
+                                 firstname=data.get(qname('firstname')),
+                                 surname=data.get(qname('surname')))
+                cnx.commit()
         except ValidationError, err:
             err_raised = True
             # XXX TEMPORARY HACK to allow registration links to work more than
@@ -178,8 +181,9 @@ class RegisterLink(basecomponents.HeaderComponent):
     context = 'header-right'
 
     def render(self, w):
-        w(u'[<a class="logout" href="%s">%s</a>]' % (
-            self._cw.build_url('register'), self._cw._('i18n_register_user')))
+        self._cw.add_css('cubicweb.pictograms.css')
+        w(u'<a class="logout icon-user-add" title="%s" href="%s"></a>' % (
+                self._cw._('i18n_register_user'), self._cw.build_url('register'), ))
 
 ## urls #######################################################################
 
